@@ -8,8 +8,6 @@
 {% endif %}{% if gres       %}#SBATCH --gres={{gres}}
 {% endif %}{% if nprocs     %}#SBATCH --cpus-per-task={{nprocs}}
 {% endif %}{% if reservation%}#SBATCH --reservation={{reservation}}
-{% endif %}{% if nnodes     %}#SBATCH --nodes={{nnodes}}
-{% endif %}{% if ntasks     %}#SBATCH --ntasks-per-node={{ntasks}}
 {% endif %}{% if exclusive  %}#SBATCH --exclusive
 {% endif %}{% if not output %}#SBATCH --output=/dev/null
 {% endif %}{% if options %}#SBATCH {{options}}
@@ -18,5 +16,5 @@
 set -euo pipefail
 
 trap 'echo SIGTERM received' TERM
-
+{{prologue}}
 {{cmd}}
